import React from "react";

import dateFormat from "dateformat";
import { isInSameDay } from "../../../util/common";

export interface TimeProps {
  timestamp: number;
  fullTime?: boolean;
}

function Time({ timestamp, fullTime }: TimeProps) {
  const date = new Date(timestamp);

  const formattedFullTime = dateFormat(date, "dd mmmm yyyy, hh:MM TT");
  let formattedDateTime = formattedFullTime;

  if (!fullTime) {
    const compareDate = new Date();
    const isToday = isInSameDay(date, compareDate);
    compareDate.setDate(compareDate.getDate() - 1);
    const isYesterday = isInSameDay(date, compareDate);

    const dtf = new Intl.DateTimeFormat();
    const formattedDate = dtf.format(date);

    formattedDateTime = dateFormat(
      date,
      isToday || isYesterday ? "hh:MM TT" : formattedDate
    );
    if (isYesterday) {
      formattedDateTime = `Yesterday, ${formattedDateTime}`;
    }
  }

  return (
    <time dateTime={date.toISOString()} title={formattedFullTime}>
      {formattedDateTime}
    </time>
  );
}

Time.defaultProps = {
  fullTime: false,
};

export default Time;
